# City of Grand Rapids Parking Analytics
This package includes libraries of functions to export, transform, and load data from the City of Grand Rapids' off-street and on-street parking systems.
#### Parking System Included
* Amano McGann
* Designa